package repos

import (
	"context"
	"gralias/models"

	"github.com/jmoiron/sqlx"
)

type CardMarksRepo interface {
	CardMarksByCardID(ctx context.Context, cardID string) ([]models.CardMark, error)
	CardMarksAdd(ctx context.Context, cm *models.CardMark) error
	CardMarksRemove(ctx context.Context, cardID, username string) error
}

type cardMarksRepo struct {
	db *sqlx.DB
}

func NewCardMarksRepo(db *sqlx.DB) CardMarksRepo {
	return &cardMarksRepo{db: db}
}

func (r *cardMarksRepo) CardMarksByCardID(ctx context.Context, cardID string) ([]models.CardMark, error) {
	var cardMarks []models.CardMark
		err := sqlx.SelectContext(ctx, getDB(ctx, r.db), &cardMarks, "SELECT * FROM card_marks WHERE card_id = ?", cardID)
	return cardMarks, err
}

func (r *cardMarksRepo) CardMarksAdd(ctx context.Context, cm *models.CardMark) error {
			_, err := getDB(ctx, r.db).ExecContext(ctx, "INSERT INTO card_marks (card_id, username, mark_type) VALUES (?, ?, ?)", cm.CardID, cm.Username, cm.MarkType)
	return err
}

func (r *cardMarksRepo) CardMarksRemove(ctx context.Context, cardID, username string) error {
	db := getDB(ctx, r.db)
	_, err := db.ExecContext(ctx, "DELETE FROM card_marks WHERE card_id = ? AND username = ?", cardID, username)
	return err
}